%define with_maven 1

Name:           cal10n
Version:        0.7.4
Release:        %mkrel 2
Summary:        Compiler assisted localization library (CAL10N)

Group:          Development/Java
License:        MIT
URL:            http://cal10n.qos.ch
Source0:        http://cal10n.qos.ch/dist/cal10n-%{version}.tar.gz
Source1:        build.xml.tar.bz2
Patch0:         %{name}-fix-maven.patch
Patch1:         build.xml-fix-hardcoded-value.patch 

BuildArch: noarch

BuildRequires: junit4
BuildRequires: java-devel >= 1.6.0
BuildRequires: ant
BuildRequires: java-rpmbuild
BuildRequires: jpackage-utils
%if %{with_maven}
BuildRequires: maven
BuildRequires: maven-assembly-plugin
BuildRequires: maven-compiler-plugin
BuildRequires: maven-install-plugin
BuildRequires: maven-jar-plugin
BuildRequires: maven-javadoc-plugin
BuildRequires: maven-plugin-plugin
BuildRequires: maven-resources-plugin
BuildRequires: maven-source-plugin
BuildRequires: maven-doxia-sitetools
BuildRequires: maven-site-plugin
BuildRequires: maven-surefire-maven-plugin
BuildRequires: maven-surefire-provider-junit4
BuildRequires: forge-parent
%endif

Requires:      java
Requires(post):   jpackage-utils >= 1.7.3
Requires(postun): jpackage-utils >= 1.7.3

%description
Compiler Assisted Localization, abbreviated as CAL10N (pronounced as "calion") 
is a java library for writing localized (internationalized) messages.
Features:
    * java compiler verifies message keys used in source code
    * tooling to detect errors in message keys
    * native2ascii tool made superfluous, as you can directly encode bundles 
      in the most convenient charset, per locale.
    * good performance (300 nanoseconds per key look-up)
    * automatic reloading of resource bundles upon change


%package javadoc
Group:          Development/Java
Summary:        Javadoc for %{name}
Requires:       jpackage-utils

%description javadoc
API documentation for %{name}.

%package -n maven-cal10n-plugin
Summary:    CAL10N maven plugin
Group:      Development/Java
Requires:   maven
Requires:   %{name} = %{version}-%{release}

%description -n maven-cal10n-plugin
Maven plugin verifying that the codes defined in
an enum type match those in the corresponding resource bundles. 

%package -n maven-cal10n-smoke-plugin
Summary:    CAL10N maven plugin - Maven Testing
Group:      Development/Java
Requires:   maven
Requires:   %{name} = %{version}-%{release}
Requires:   maven-cal10n-plugin = %{version}-%{release}

%description -n maven-cal10n-smoke-plugin
Maven Testing plugin verifying that the codes defined in
an enum type match those in the corresponding resource bundles. 

%prep
%setup -q

find . -name "*.jar" | xargs rm
%patch0

%if !%{with_maven}
tar -xf %{SOURCE1} 
%patch1 -p0
sed -e 's,TOPDIR,%{_topdir},g' -i cal10n-api/maven-build.xml
sed -i 's,<module>maven-cal10n-plugin</module>,<!--module>maven-cal10n-plugin</module-->,' pom.xml
sed -i 's,<module>maven-cal10n-plugin-smoke</module>,<!--module>maven-cal10n-plugin-smoke</module-->,' pom.xml
%endif

%build

%if %{with_maven}
  mvn-rpmbuild install javadoc:aggregate
%else
#CLASSPATH=$CLASSPATH:$(pwd)/cal10n-api/target/classes
#CLASSPATH=$CLASSPATH:$(pwd)/cal10n-site/target/classes
#CLASSPATH=$CLASSPATH:$(pwd)/maven-cal10n-plugin/target/classes
#CLASSPATH=$CLASSPATH:$(pwd)/maven-cal10n-plugin-smoke/target/classes
#CLASSPATH=$CLASSPATH:target/classes:target/test-classes
ant -Dmaven.mode.offline=true package javadoc \
    -lib /usr/share/java
%endif

%install

# jars
install -d -m 0755 %{buildroot}%{_javadir}/%{name}
install -m 644 %{name}-api/target/%{name}-api-%{version}.jar \
        %{buildroot}%{_javadir}/%{name}/%{name}-api.jar
install -m 644 %{name}-site/target/%{name}-site-%{version}.jar \
        %{buildroot}%{_javadir}/%{name}/%{name}-site.jar

%if %{with_maven}
install -m 644 maven-%{name}-plugin/target/maven-%{name}-plugin-%{version}.jar \
  %{buildroot}%{_javadir}/%{name}/maven-%{name}-plugin.jar
install -m 644 maven-%{name}-plugin-smoke/target/maven-%{name}-plugin-smoke-%{version}.jar \
  %{buildroot}%{_javadir}/%{name}/maven-%{name}-plugin-smoke.jar
%endif

# poms
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -pm 644 pom.xml \
    %{buildroot}%{_mavenpomdir}/JPP.%{name}-%{name}-parent.pom
%add_maven_depmap JPP.%{name}-%{name}-parent.pom
install -pm 644 %{name}-api/pom.xml \
    %{buildroot}%{_mavenpomdir}/JPP.%{name}-%{name}-api.pom
%add_maven_depmap JPP.%{name}-%{name}-api.pom %{name}/%{name}-api.jar
install -pm 644 %{name}-site/pom.xml \
    %{buildroot}%{_mavenpomdir}/JPP.%{name}-%{name}-site.pom
%add_maven_depmap JPP.%{name}-%{name}-site.pom %{name}/%{name}-site.jar

%if %{with_maven}
install -pm 644 maven-%{name}-plugin/pom.xml \
    %{buildroot}%{_mavenpomdir}/JPP.%{name}-maven-%{name}-plugin.pom
%add_maven_depmap -f maven-plugin JPP.%{name}-maven-%{name}-plugin.pom %{name}/maven-%{name}-plugin.jar
install -pm 644 maven-%{name}-plugin-smoke/pom.xml \
    %{buildroot}%{_mavenpomdir}/JPP.%{name}-maven-%{name}-plugin-smoke.pom
%add_maven_depmap -f smoke-plugin JPP.%{name}-maven-%{name}-plugin-smoke.pom %{name}/maven-%{name}-plugin-smoke.jar
%endif

# javadoc
install -d -m 0755 %{buildroot}%{_javadocdir}/%{name}
%if %{with_maven}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}
%else
cp -pr cal10n-api/target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}
%endif


%files
%dir %{_javadir}/%{name}
%{_javadir}/%{name}/%{name}-api.jar
%{_javadir}/%{name}/%{name}-site.jar
%{_mavenpomdir}/JPP.%{name}-%{name}-parent.pom
%{_mavenpomdir}/JPP.%{name}-%{name}-api.pom
%{_mavenpomdir}/JPP.%{name}-%{name}-site.pom
%{_mavendepmapfragdir}/%{name}

%if %{with_maven}
%files -n maven-cal10n-plugin
%{_javadir}/%{name}/maven-%{name}-plugin.jar
%{_mavenpomdir}/JPP.%{name}-maven-%{name}-plugin.pom
%{_mavendepmapfragdir}/%{name}-maven-plugin

%files -n maven-cal10n-smoke-plugin
%{_javadir}/%{name}/maven-%{name}-plugin-smoke.jar
%{_mavenpomdir}/JPP.%{name}-maven-%{name}-plugin-smoke.pom
%{_mavendepmapfragdir}/%{name}-smoke-plugin
%endif

%pre javadoc
# workaround for rpm bug 646523
[ $1 -gt 1 ] && [ -L %{_javadocdir}/%{name} ] && \
rm -rf $(readlink -f %{_javadocdir}/%{name}) %{_javadocdir}/%{name} || :

%files javadoc
%{_javadocdir}/%{name}


%changelog

* Sun Jan 22 2012 gil <gil> 0.7.4-2.mga2
+ Revision: 199740
- build fix
  build with maven 3 support
  adapt to current guidelines
  new sub package maven-cal10n-smoke-plugin

* Thu Jan 20 2011 dmorgan <dmorgan> 0.7.4-1.mga1
+ Revision: 27288
- Ooooops i removed the wrong file
- Fix file list
- Fix docs
- Fix file list
- Fix jar file install
- Fix jar file name
- Fix hardcoded value
- Adapt to mageia
- Use OpenSource spec file for bootstraping
- imported package cal10n


* Thu Nov 25 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.7.4-4
- Fix pom filenames (Resolves rhbz#655792)
- Add several packages to Requires
- Remove versioned jars and javadocs

* Wed Sep 8 2010 Alexander Kurtakov <akurtako@redhat.com> 0.7.4-3
- Fix build failure (javadoc:aggregate).

* Mon Jul 19 2010 Alexander Kurtakov <akurtako@redhat.com> 0.7.4-2
- BR maven-site-plugin.

* Mon Jul 19 2010 Alexander Kurtakov <akurtako@redhat.com> 0.7.4-1
- Update to 0.7.4.

* Wed Feb 3 2010 Alexander Kurtakov <akurtako@redhat.com> 0.7.2-2
- Removed not needed external repo definitions.
- Use _mavenpomdir.

* Wed Feb 3 2010 Alexander Kurtakov <akurtako@redhat.com> 0.7.2-1
- Initial package
